@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Base;
 
-our $DATE = '2016-03-16'; # DATE
-our $VERSION = '1.52'; # VERSION
+our $DATE = '2016-04-04'; # DATE
+our $VERSION = '1.53'; # VERSION
 
 use 5.010001;
 use strict;
@@ -923,7 +923,11 @@ sub _parse_argv2 {
                 my %a = @_;
 
                 my ($an, $aa, $as) = ($a{arg}, $a{args}, $a{spec});
-                my $src = $as->{cmdline_src};
+                my $src = $as->{cmdline_src} // '';
+
+                # we only get from stdin if stdin is piped
+                $src = '' if $src eq 'stdin_or_args' && -t STDIN;
+
                 if ($src && $as->{req}) {
                     # don't complain, we will fill argument from other source
                     return 1;
@@ -1135,7 +1139,7 @@ sub parse_cmdline_src {
                             $is_ary ? [<>] :
                                 do {local $/; ~~<>};
                     $r->{args}{"-cmdline_src_$an"} = $src;
-                } elsif ($src eq 'stdin_or_args') {
+                } elsif ($src eq 'stdin_or_args' && !(-t STDIN)) {
                     unless (defined($r->{args}{$an})) {
                         $r->{args}{$an} = $do_stream ?
                             __gen_iter(\*STDIN, $as, $an) :
@@ -1435,7 +1439,7 @@ Perinci::CmdLine::Base - Base class for Perinci::CmdLine{::Classic,::Lite}
 
 =head1 VERSION
 
-This document describes version 1.52 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2016-03-16.
+This document describes version 1.53 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2016-04-04.
 
 =head1 DESCRIPTION
 
@@ -2244,7 +2248,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Cm
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Perinci-CmdLine-Lite>.
+Source repository is at L<https://github.com/perlancar/perl-Perinci-CmdLine-Lite>.
 
 =head1 BUGS
 
